@@ -53,7 +53,7 @@ class NSML(TypedConfig):
 
 
 Storage = Union[Local, S3]
-Reporter = Union[Logger]
+Reporter = Union[Logger, NSML]
 
 
 class Checker(Config):
